# DatasetResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**data_query** | [**DatasetJoinedDataQueryResponseDto**](DatasetJoinedDataQueryResponseDto.md) |  | [optional] 
**dataset_columns** | [**list[DatasetJoinedDatasetColumnResponseDto]**](DatasetJoinedDatasetColumnResponseDto.md) |  | [optional] 
**id** | **str** |  | [optional] 
**name** | **str** |  | 
**description** | **str** |  | [optional] 
**tags** | **list[str]** |  | [optional] 
**type** | **object** |  | 
**model_type** | **str** |  | [optional] 
**outcome_type** | **object** |  | [optional] 
**treatment_type** | **object** |  | [optional] 
**location** | **str** |  | [optional] 
**snowflake_location** | **str** |  | [optional] 
**file_content_type** | **str** |  | [optional] 
**file_size** | **str** |  | [optional] 
**file_type** | **str** |  | [optional] 
**row_count** | **str** |  | [optional] 
**column_count** | **float** |  | [optional] 
**status** | **str** |  | [optional] 
**is_downloadable** | **bool** |  | [optional] 
**organization_id** | **str** |  | 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

